<?php
class ControllerExtensionModuleProductWarranty extends Controller {
    private $error = [];
    private $version = '1.0';

    public function index() {
        $this->load->language('extension/module/product_warranty');

		$this->document->setTitle($this->language->get('heading_title'));

        $this->load->model('setting/setting');
        
        if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validateForm()) {
            $this->model_setting_setting->editSetting('module_product_warranty', $this->request->post, $this->config->get('config_store_id'));

			$this->session->data['success'] = $this->language->get('text_success');

			$this->response->redirect($this->url->link('extension/extension', 'token=' . $this->session->data['token'] . '&type=module', true));
        }

        $data['breadcrumbs'] = array();

		$data['breadcrumbs'][] = array(
			'text'      => $this->language->get('text_home'),
			'href'      => $this->url->link('common/dashboard', 'token=' . $this->session->data['token'], true)
		);

		$data['breadcrumbs'][] = array(
			'text'      => $this->language->get('text_extension'),
			'href'      => $this->url->link('extension/extension', 'token=' . $this->session->data['token'] . '&type=module', true)
		);

        if (!isset($this->request->get['module_id'])) {
			$data['breadcrumbs'][] = array(
				'text' => $this->language->get('heading_title'),
				'href' => $this->url->link('extension/module/product_warranty', 'token=' . $this->session->data['token'], true)
			);
		} else {
			$data['breadcrumbs'][] = array(
				'text' => $this->language->get('heading_title'),
				'href' => $this->url->link('extension/module/product_warranty', 'token=' . $this->session->data['token'] . '&module_id=' . $this->request->get['module_id'], true)
			);
		}

		$language_arr = ['button_save', 'button_cancel', 'text_form', 'heading_title', 'entry_status', 'text_enabled', 'text_disabled'];

		foreach ($language_arr as $language) {
			$data[$language] = $this->language->get($language);
		}

        if (isset($this->error['warning'])) {
			$data['error_warning'] = $this->error['warning'];
		} else {
			$data['error_warning'] = '';
		}
    
        if (isset($this->session->data['success'])) {
			$data['success'] = $this->session->data['success'];
			unset($this->session->data['success']);
		} else {
			$data['success'] = '';
		}

		if (isset($this->request->post['module_product_warranty_status'])) {
			$data['module_product_warranty_status'] = $this->request->post['module_product_warranty_status'];
		} elseif ($this->config->get('module_product_warranty_status')){
			$data['module_product_warranty_status'] = $this->config->get('module_product_warranty_status');
		} else {
			$data['module_product_warranty_status'] = '';
        }
        
        $data['action'] = $this->url->link('extension/module/product_warranty', 'token=' . $this->session->data['token'], true);

        $data['cancel'] = $this->url->link('extension/extension', 'token=' . $this->session->data['token'] . '&type=module', true);

        $data['header'] = $this->load->controller('common/header');
		$data['column_left'] = $this->load->controller('common/column_left');
		$data['footer'] = $this->load->controller('common/footer');

		$this->response->setOutput($this->load->view('extension/module/product_warranty', $data));
	}

    public function install(){
        $this->load->model('extension/module/product_warranty');

        $this->model_extension_module_product_warranty->install();
    }

    public function uninstall(){
        $this->load->model('extension/module/product_warranty');
        $this->load->model('setting/setting');
        $this->load->model('setting/modification');

        $this->model_extension_module_product_warranty->uninstall();

        $modification = $this->model_setting_modification->getModificationByCode('product_warranty');

        if (!empty($modification)) {
            $this->model_setting_modification->disableModification($modification['modification_id']);
        }

        $this->model_setting_setting->deleteSetting('product_warranty');
	}
	
	public function warranty_list() {
		$this->load->language('extension/module/product_warranty');
		
		$this->document->setTitle($this->language->get('heading_title'));

        $this->load->model('extension/module/product_warranty');

		$this->getList();
	}

	public function add_warranty() {
		$this->load->language('extension/module/product_warranty');
		
		$this->document->setTitle($this->language->get('heading_title'));

        $this->load->model('extension/module/product_warranty');
        $this->load->model('localisation/language');

        if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validateWarrantyForm()) {
			$this->model_extension_module_product_warranty->addProductWarranty($this->request->post);

			$this->session->data['success'] = $this->language->get('text_success');

			$url = '';

			if (isset($this->request->get['filter_name'])) {
				$url .= '&filter_name=' . urlencode(html_entity_decode($this->request->get['filter_name'], ENT_QUOTES, 'UTF-8'));
			}

			if (isset($this->request->get['filter_status'])) {
				$url .= '&filter_status=' . $this->request->get['filter_status'];
			}

			if (isset($this->request->get['sort'])) {
				$url .= '&sort=' . $this->request->get['sort'];
			}

			if (isset($this->request->get['order'])) {
				$url .= '&order=' . $this->request->get['order'];
			}

			if (isset($this->request->get['page'])) {
				$url .= '&page=' . $this->request->get['page'];
			}

			$this->response->redirect($this->url->link('extension/module/product_warranty/warranty_list', 'token=' . $this->session->data['token'] . $url, true));
		}

		$this->getForm();
	}

	public function edit_warranty() {
		$this->load->language('extension/module/product_warranty');
		
		$this->document->setTitle($this->language->get('heading_title'));

        $this->load->model('extension/module/product_warranty');
		$this->load->model('localisation/language');

        if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validateWarrantyForm()) {
			$this->model_extension_module_product_warranty->editProductWarranty($this->request->post, $this->request->get['product_warranty_id']);

			$this->session->data['success'] = $this->language->get('text_success');

			$url = '';

			if (isset($this->request->get['filter_name'])) {
				$url .= '&filter_name=' . urlencode(html_entity_decode($this->request->get['filter_name'], ENT_QUOTES, 'UTF-8'));
			}

			if (isset($this->request->get['filter_status'])) {
				$url .= '&filter_status=' . $this->request->get['filter_status'];
			}

			if (isset($this->request->get['sort'])) {
				$url .= '&sort=' . $this->request->get['sort'];
			}

			if (isset($this->request->get['order'])) {
				$url .= '&order=' . $this->request->get['order'];
			}

			if (isset($this->request->get['page'])) {
				$url .= '&page=' . $this->request->get['page'];
			}

			$this->response->redirect($this->url->link('extension/module/product_warranty/warranty_list', 'token=' . $this->session->data['token'] . $url, true));
		}
		
		$this->getForm();
	}

	public function delete_warranty() {
		$this->load->language('extension/module/product_warranty');
		
		$this->document->setTitle($this->language->get('heading_title'));

        $this->load->model('extension/module/product_warranty');

        if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validateDelete()) {
			foreach ($this->request->post['selected'] as $product_warranty_id) {
				$this->model_extension_module_product_warranty->deleteProductWarranty($product_warranty_id);
			}

			$this->session->data['success'] = $this->language->get('text_success');

			$url = '';

			if (isset($this->request->get['filter_name'])) {
				$url .= '&filter_name=' . urlencode(html_entity_decode($this->request->get['filter_name'], ENT_QUOTES, 'UTF-8'));
			}

			if (isset($this->request->get['filter_status'])) {
				$url .= '&filter_status=' . $this->request->get['filter_status'];
			}

			if (isset($this->request->get['sort'])) {
				$url .= '&sort=' . $this->request->get['sort'];
			}

			if (isset($this->request->get['order'])) {
				$url .= '&order=' . $this->request->get['order'];
			}

			if (isset($this->request->get['page'])) {
				$url .= '&page=' . $this->request->get['page'];
			}

			$this->response->redirect($this->url->link('extension/module/product_warranty/warranty_list', 'token=' . $this->session->data['token'] . $url, true));
		}

		$this->getList();
	}

	protected function getList() {
		if (isset($this->request->get['filter_name'])) {
			$filter_name = $this->request->get['filter_name'];
		} else {
			$filter_name = '';
		}

		if (isset($this->request->get['filter_status'])) {
			$filter_status = $this->request->get['filter_status'];
		} else {
			$filter_status = '';
		}

		if (isset($this->request->get['sort'])) {
			$sort = $this->request->get['sort'];
		} else {
			$sort = 'pwd.name';
		}

		if (isset($this->request->get['order'])) {
			$order = $this->request->get['order'];
		} else {
			$order = 'ASC';
		}

		if (isset($this->request->get['page'])) {
			$page = $this->request->get['page'];
		} else {
			$page = 1;
		}

		$url = '';

		if (isset($this->request->get['filter_name'])) {
			$url .= '&filter_name=' . urlencode(html_entity_decode($this->request->get['filter_name'], ENT_QUOTES, 'UTF-8'));
		}

		if (isset($this->request->get['filter_status'])) {
			$url .= '&filter_status=' . $this->request->get['filter_status'];
		}

		if (isset($this->request->get['order'])) {
			$url .= '&order=' . $this->request->get['order'];
		}

		if (isset($this->request->get['page'])) {
			$url .= '&page=' . $this->request->get['page'];
		}

		$data['breadcrumbs'] = array();

		$data['breadcrumbs'][] = array(
			'text'      => $this->language->get('text_home'),
			'href'      => $this->url->link('common/dashboard', 'token=' . $this->session->data['token'], true)
		);
	
		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('heading_title'),
			'href' => $this->url->link('extension/module/product_warranty/warranty_list', 'token=' . $this->session->data['token'] . $url, true)
		);
		
		$data['add'] = $this->url->link('extension/module/product_warranty/add_warranty', 'token=' . $this->session->data['token'] . $url, true);
		$data['delete'] = $this->url->link('extension/module/product_warranty/delete_warranty', 'token=' . $this->session->data['token'] . $url, true);

		$language_arr = ['heading_title', 'button_add', 'button_delete', 'entry_status', 'entry_name', 'text_list', 'button_filter', 'column_action', 'text_no_results', 'column_name', 'column_sort_order', 'column_status', 'text_enabled', 'text_disabled', 'text_confirm', 'button_edit'];

		foreach ($language_arr as $language) {
			$data[$language] = $this->language->get($language);
		}

		$data['product_warranties'] = array();

		$filter_data = array(
			'filter_name'	  => $filter_name,
			'filter_status'   => $filter_status,
			'sort'            => $sort,
			'order'           => $order,
			'start'           => ($page - 1) * $this->config->get('config_limit_admin'),
			'limit'           => $this->config->get('config_limit_admin')
		);

		$product_warranty_total = $this->model_extension_module_product_warranty->getTotalProductWarranties($filter_data);

		$results = $this->model_extension_module_product_warranty->getProductWarranties($filter_data);

		if (!empty($results)) {
			foreach ($results as $result) {
				$data['product_warranties'][] = [
					'product_warranty_id'		=> $result['product_warranty_id'],
					'name'						=> $result['name'],
					'sort_order'				=> $result['sort_order'],
					'status'					=> ($result['status'] > 0) ? $this->language->get('text_enabled') : $this->language->get('text_disabled'),
					'edit'						=> $this->url->link('extension/module/product_warranty/edit_warranty', 'token=' . $this->session->data['token'] . '&product_warranty_id=' . $result['product_warranty_id'] . $url, true)
				];
			}
		}

        if (isset($this->error['warning'])) {
			$data['error_warning'] = $this->error['warning'];
		} else {
			$data['error_warning'] = '';
		}
    
        if (isset($this->session->data['success'])) {
			$data['success'] = $this->session->data['success'];
			unset($this->session->data['success']);
		} else {
			$data['success'] = '';
		}

		if (isset($this->request->post['selected'])) {
			$data['selected'] = (array)$this->request->post['selected'];
		} else {
			$data['selected'] = array();
		}

		$url = '';

		if (isset($this->request->get['filter_name'])) {
			$url .= '&filter_name=' . urlencode(html_entity_decode($this->request->get['filter_name'], ENT_QUOTES, 'UTF-8'));
		}

		if (isset($this->request->get['filter_status'])) {
			$url .= '&filter_status=' . $this->request->get['filter_status'];
		}

		if ($order == 'ASC') {
			$url .= '&order=DESC';
		} else {
			$url .= '&order=ASC';
		}

		if (isset($this->request->get['page'])) {
			$url .= '&page=' . $this->request->get['page'];
		}

		$data['sort_name'] = $this->url->link('extension/module/product_warranty/warranty_list', 'token=' . $this->session->data['token'] . '&sort=pwd.name' . $url, true);
		$data['sort_status'] = $this->url->link('extension/module/product_warranty/warranty_list', 'token=' . $this->session->data['token'] . '&sort=pw.status' . $url, true);
		$data['sort_sort_order'] = $this->url->link('extension/module/product_warranty/warranty_list', 'token=' . $this->session->data['token'] . '&sort=pw.sort_order' . $url, true);

		$url = '';

		if (isset($this->request->get['filter_name'])) {
			$url .= '&filter_name=' . urlencode(html_entity_decode($this->request->get['filter_name'], ENT_QUOTES, 'UTF-8'));
		}

		if (isset($this->request->get['filter_status'])) {
			$url .= '&filter_status=' . $this->request->get['filter_status'];
		}

		if (isset($this->request->get['sort'])) {
			$url .= '&sort=' . $this->request->get['sort'];
		}

		if (isset($this->request->get['order'])) {
			$url .= '&order=' . $this->request->get['order'];
		}

		$pagination = new Pagination();
		$pagination->total = $product_warranty_total;
		$pagination->page = $page;
		$pagination->limit = $this->config->get('config_limit_admin');
		$pagination->url = $this->url->link('extension/module/product_warranty/warranty_list', 'token=' . $this->session->data['token'] . $url . '&page={page}', true);

		$data['pagination'] = $pagination->render();

		$data['results'] = sprintf($this->language->get('text_pagination'), ($product_warranty_total) ? (($page - 1) * $this->config->get('config_limit_admin')) + 1 : 0, ((($page - 1) * $this->config->get('config_limit_admin')) > ($product_warranty_total - $this->config->get('config_limit_admin'))) ? $product_warranty_total : ((($page - 1) * $this->config->get('config_limit_admin')) + $this->config->get('config_limit_admin')), $product_warranty_total, ceil($product_warranty_total / $this->config->get('config_limit_admin')));

		$data['filter_name'] = $filter_name;
		$data['filter_status'] = $filter_status;

		$data['sort'] = $sort;
		$data['order'] = $order;

		$data['token'] = $this->session->data['token'];
		
        $data['header'] = $this->load->controller('common/header');
		$data['column_left'] = $this->load->controller('common/column_left');
		$data['footer'] = $this->load->controller('common/footer');

		$this->response->setOutput($this->load->view('extension/module/product_warranty_list', $data));
	}

	protected function getForm() {
		$url = '';

		if (isset($this->request->get['filter_name'])) {
			$url .= '&filter_name=' . urlencode(html_entity_decode($this->request->get['filter_name'], ENT_QUOTES, 'UTF-8'));
		}

		if (isset($this->request->get['filter_status'])) {
			$url .= '&filter_status=' . $this->request->get['filter_status'];
		}

		if (isset($this->request->get['order'])) {
			$url .= '&order=' . $this->request->get['order'];
		}

		if (isset($this->request->get['page'])) {
			$url .= '&page=' . $this->request->get['page'];
		}

		$data['breadcrumbs'] = array();

		$data['breadcrumbs'][] = array(
			'text'      => $this->language->get('text_home'),
			'href'      => $this->url->link('common/dashboard', 'token=' . $this->session->data['token'], true)
		);
	
		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('heading_title'),
			'href' => $this->url->link('extension/module/product_warranty/warranty_list', 'token=' . $this->session->data['token'] . $url, true)
		);
		
		$data['cancel'] = $this->url->link('extension/module/product_warranty/warranty_list', 'token=' . $this->session->data['token'] . $url, true);
		$data['action'] = isset($this->request->get['product_warranty_id']) ? $this->url->link('extension/module/product_warranty/edit_warranty', 'token=' . $this->session->data['token'] . '&product_warranty_id=' . $this->request->get['product_warranty_id'] . $url, true) : $this->url->link('extension/module/product_warranty/add_warranty', 'token=' . $this->session->data['token'] . $url, true);

		$language_arr = ['heading_title', 'button_save', 'button_cancel', 'entry_status', 'entry_name', 'entry_sort_order', 'text_enabled', 'text_disabled'];

		foreach ($language_arr as $language) {
			$data[$language] = $this->language->get($language);
		}

		$data['text_form'] = isset($this->request->get['product_warranty_id']) ? $this->language->get('text_edit') : $this->language->get('text_add');

		if (isset($this->request->get['product_warranty_id']) && ($this->request->server['REQUEST_METHOD'] != 'POST')) {
			$product_warranty_info = $this->model_extension_module_product_warranty->getProductWarranty($this->request->get['product_warranty_id']);
		}

		if (isset($this->error['warning'])) {
			$data['error_warning'] = $this->error['warning'];
		} else {
			$data['error_warning'] = '';
		}

		if (isset($this->error['name'])) {
			$data['error_name'] = $this->error['name'];
		} else {
			$data['error_name'] = [];
		}

		if (isset($this->request->post['name'])) {
			$data['name'] = $this->request->post['name'];
		} elseif (isset($this->request->get['product_warranty_id'])){
			$data['name'] = $this->model_extension_module_product_warranty->getProductWarrantyNames($this->request->get['product_warranty_id']);
		} else {
			$data['name'] = [];
		}

		if (isset($this->request->post['status'])) {
			$data['status'] = $this->request->post['status'];
		} elseif (!empty($product_warranty_info)) {
			$data['status'] = $product_warranty_info['status'];
		} else {
			$data['status'] = true;
		}
		
		if (isset($this->request->post['sort_order'])) {
			$data['sort_order'] = $this->request->post['sort_order'];
		} elseif (!empty($product_warranty_info)) {
			$data['sort_order'] = $product_warranty_info['sort_order'];
		} else {
			$data['sort_order'] = '';
		}

        $data['languages'] = $this->model_localisation_language->getLanguages();

        $data['header'] = $this->load->controller('common/header');
		$data['column_left'] = $this->load->controller('common/column_left');
		$data['footer'] = $this->load->controller('common/footer');

		$this->response->setOutput($this->load->view('extension/module/product_warranty_form', $data));
	}

    protected function validateForm(){
        if (!$this->user->hasPermission('modify', 'extension/module/product_warranty')) {
			$this->error['warning'] = $this->language->get('error_permission');
		}

		if ($this->error && !isset($this->error['warning'])) {
			$this->error['warning'] = $this->language->get('error_warning');
		}

		return !$this->error;
	}
	
	protected function validateWarrantyForm() {
		if (!$this->user->hasPermission('modify', 'extension/module/product_warranty')) {
			$this->error['warning'] = $this->language->get('error_permission');
		}

		foreach ($this->request->post['name'] as $language_id => $value){
            if (empty($value)) {
    			$this->error['name'][$language_id] = $this->language->get('error_name');
    		}
        }

		if ($this->error && !isset($this->error['warning'])) {
			$this->error['warning'] = $this->language->get('error_warning');
		}

		return !$this->error;
	}

	protected function validateDelete() {
		if (!$this->user->hasPermission('modify', 'extension/module/product_warranty')) {
			$this->error['warning'] = $this->language->get('error_permission');
		}

		return !$this->error;
	}
}
?>