<?php
class ModelExtensionModuleProductWarranty extends Model {
    public function install(){
        $this->db->query("CREATE TABLE IF NOT EXISTS " . DB_PREFIX . "product_warranty (product_warranty_id INT(11) NOT NULL AUTO_INCREMENT, sort_order INT(11) NOT NULL, status INT(11) NOT NULL, date_added DATETIME NOT NULL, date_modified DATETIME NOT NULL, PRIMARY KEY (product_warranty_id)) ENGINE=MyISAM DEFAULT CHARSET=utf8");

        $this->db->query("CREATE TABLE IF NOT EXISTS " . DB_PREFIX . "product_warranty_description (product_warranty_id INT(11) NOT NULL, language_id INT(11) NOT NULL, name VARCHAR(255) NOT NULL, PRIMARY KEY (product_warranty_id, language_id)) ENGINE=MyISAM DEFAULT CHARSET=utf8");

        $this->db->query("ALTER TABLE " . DB_PREFIX . "product ADD `product_warranty_id` INT(11) NOT NULL AFTER `manufacturer_id`");
    }

    public function uninstall(){
        $this->db->query("DROP TABLE " . DB_PREFIX . "product_warranty");

        $this->db->query("DROP TABLE " . DB_PREFIX . "product_warranty_description");

        $this->db->query("ALTER TABLE " . DB_PREFIX . "product DROP `product_warranty_id`");
    }

    public function getProductWarranty($product_warranty_id) {
        $sql = "SELECT * FROM " . DB_PREFIX . "product_warranty pw LEFT JOIN " . DB_PREFIX . "product_warranty_description pwd ON pwd.product_warranty_id = pw.product_warranty_id AND pwd.language_id = '" . (int)$this->config->get('config_language_id') . "' WHERE pw.product_warranty_id = '" . (int)$product_warranty_id . "'";

        $query = $this->db->query($sql);

		return $query->row;
    }
    
	public function getProductWarrantyNames($product_warranty_id) {
		$product_warranty_description_data = [];

		$query = $this->db->query("SELECT * FROM " . DB_PREFIX . "product_warranty_description WHERE product_warranty_id = '" . (int)$product_warranty_id . "'");

		foreach ($query->rows as $result) {
			$product_warranty_description_data[$result['language_id']] = $result['name'];
		}

		return $product_warranty_description_data;
    }
    
    public function getAllProductWarranties() {
        $sql = "SELECT * FROM " . DB_PREFIX . "product_warranty pw LEFT JOIN " . DB_PREFIX . "product_warranty_description pwd ON pwd.product_warranty_id = pw.product_warranty_id AND pwd.language_id = '" . (int)$this->config->get('config_language_id') . "' WHERE pw.status = '1' ORDER BY pw.sort_order ASC";

        $query = $this->db->query($sql);

		return $query->rows;
    }

    public function getProductWarranties($data) {
        $sql = "SELECT * FROM " . DB_PREFIX . "product_warranty pw LEFT JOIN " . DB_PREFIX . "product_warranty_description pwd ON pwd.product_warranty_id = pw.product_warranty_id AND pwd.language_id = '" . (int)$this->config->get('config_language_id') . "' WHERE 1";

        if (!empty($data['filter_name'])) {
			$sql .= " AND pwd.name LIKE '%" . $this->db->escape($data['filter_name']) . "%'";
		}

		if (isset($data['filter_status']) && $data['filter_status'] !== '') {
			$sql .= " AND pw.status = '" . (int)$data['filter_status'] . "'";
		}

		$sort_data = array(
			'pwd.name',
			'pw.status',
			'pw.sort_order'
		);

		if (isset($data['sort']) && in_array($data['sort'], $sort_data)) {
			$sql .= " ORDER BY " . $data['sort'];
		} else {
			$sql .= " ORDER BY pwd.name";
		}

		if (isset($data['order']) && ($data['order'] == 'DESC')) {
			$sql .= " DESC";
		} else {
			$sql .= " ASC";
		}

		if (isset($data['start']) || isset($data['limit'])) {
			if ($data['start'] < 0) {
				$data['start'] = 0;
			}

			if ($data['limit'] < 1) {
				$data['limit'] = 20;
			}

			$sql .= " LIMIT " . (int)$data['start'] . "," . (int)$data['limit'];
		}

		$query = $this->db->query($sql);

		return $query->rows;
    }

    public function getTotalProductWarranties($data) {
        $sql = "SELECT COUNT(*) AS total FROM " . DB_PREFIX . "product_warranty pw LEFT JOIN " . DB_PREFIX . "product_warranty_description pwd ON pwd.product_warranty_id = pw.product_warranty_id AND pwd.language_id = '" . (int)$this->config->get('config_language_id') . "' WHERE 1";

        if (!empty($data['filter_name'])) {
			$sql .= " AND pwd.name LIKE '%" . $this->db->escape($data['filter_name']) . "%'";
		}

		if (isset($data['filter_status']) && $data['filter_status'] !== '') {
			$sql .= " AND pw.status = '" . (int)$data['filter_status'] . "'";
		}

		$query = $this->db->query($sql);

		return $query->row['total'];
    }

    public function addProductWarranty($data) {
        $sort_order = isset($data['sort_order']) ? $data['sort_order'] : 0;
        $status = isset($data['status']) ? $data['status'] : 0;

        $this->db->query("INSERT INTO " . DB_PREFIX . "product_warranty SET sort_order = '" . (int)$sort_order . "', status = '" . (int)$status . "', date_added = NOW(), date_modified = NOW()");

        $product_warranty_id = $this->db->getLastId();

        if (isset($data['name'])) {
            foreach ($data['name'] as $language_id => $name) {
                $this->db->query("INSERT INTO " . DB_PREFIX . "product_warranty_description SET product_warranty_id = '" . (int)$product_warranty_id . "', language_id = '" . (int)$language_id . "', name = '" . $this->db->escape($name) . "'");

            }
        }

        return $product_warranty_id;
    }

    public function editProductWarranty($data, $product_warranty_id) {
        $sort_order = isset($data['sort_order']) ? $data['sort_order'] : 0;
        $status = isset($data['status']) ? $data['status'] : 0;

        $this->db->query("UPDATE " . DB_PREFIX . "product_warranty SET sort_order = '" . (int)$sort_order . "', status = '" . (int)$status . "', date_modified = NOW() WHERE product_warranty_id = '" . (int)$product_warranty_id . "'");

        $this->db->query("DELETE FROM " . DB_PREFIX . "product_warranty_description WHERE product_warranty_id = '" . (int)$product_warranty_id . "'");

        if (isset($data['name'])) {
            foreach ($data['name'] as $language_id => $name) {
                $this->db->query("INSERT INTO " . DB_PREFIX . "product_warranty_description SET product_warranty_id = '" . (int)$product_warranty_id . "', language_id = '" . (int)$language_id . "', name = '" . $this->db->escape($name) . "'");

            }
        }
    }

    public function deleteProductWarranty($product_warranty_id) {
        $this->db->query("DELETE FROM " . DB_PREFIX . "product_warranty WHERE product_warranty_id = '" . (int)$product_warranty_id . "'");
        $this->db->query("DELETE FROM " . DB_PREFIX . "product_warranty_description WHERE product_warranty_id = '" . (int)$product_warranty_id . "'");
    }
}
?>